pygerber.parser.blender.apertures.rectangle module
==================================================

.. automodule:: pygerber.parser.blender.apertures.rectangle
   :members:
   :undoc-members:
   :show-inheritance:
